/********************************************************************
*                   LIBRERIA USO BUS ONEWIRE
* 
*   - Funciones para comunicacion onewire
*   - Hay dos velocidades, pero esta libreria usa la mas lenta 15.4Kbps 
*   - Hay mucha informacin sobre este bus:
*       - https://www.maximintegrated.com/en/app-notes/index.mvp/id/126
*       - https://datasheets.maximintegrated.com/en/ds/DS18S20.pdf
*       - http://ww1.microchip.com/downloads/en/AppNotes/01199a.pdf  
 *******************************************************************/

/* 
 * File:   
 * Author: Eduardo
 * Comments:
 * Revision history: 22/12/17
 */


// This is a guard condition so that contents of this file are not included
// more than once.  
#ifndef OneWire_H
#define	OneWire_H

#include <stdint.h>
#include <stdbool.h>
#include "config.h"


 





/******************************************************************************
*                       FUNCION INICIALIZAR BUS
* 
*   - Asigna un pin al bus
 *****************************************************************************/

void OW_begin (void);



/******************************************************************************
*                       FUNCION ENVIO RESET BUS
* 
*   - Realiza un reset para llamar la atencin de los esclavos en el bus
*   - Devuelve true, si algn esclavo responde
 *****************************************************************************/

bool reset_OW (void);



/******************************************************************************
*                       FUNCION PONE BUS A NIVEL ALTO
* 
*   - Configura el pin como salida y pone el bus a nivel alto
 *****************************************************************************/

void drive_OW_high (void);



/******************************************************************************
*                       FUNCION PONE BUS A NIVEL BAJO
* 
*   - Configura el pin como salida y pone el bus a nivel bajo
 *****************************************************************************/

void drive_OW_low (void);



/******************************************************************************
*                       FUNCION ENVIA BIT 0 o 1
* 
*   - Realiza la secuencia para transmitir un bit 0 o 1
*   - Si recibe true, envia 1, si recibe false, envia 0 
 *****************************************************************************/

void write_OW_bit (bool valor);



/******************************************************************************
*                       FUNCION LEE DEL BUS
* 
*   - Realiza la secuencia para leer del bus
*   - Devuelve true o false segn haya leido 1 o 0
 *****************************************************************************/

bool read_OW_bit (void);



/******************************************************************************
*                       FUNCION ESCRIBE BYTE EN EL BUS
* 
*   - Realiza la secuencia para transmitir 8 bits
*   - Recibe como parametro el byte a transmitir
*   - Trasmite primero el bit de menor peso 
 *****************************************************************************/

void write_OW_byte (uint8_t valor);



/******************************************************************************
*                       FUNCION LEE UN BYTE DEL BUS
* 
*   - Realiza la secuencia para leer 8 bits del bus
*   - Devuelve el byte leido
 *****************************************************************************/

uint8_t read_OW_byte ();



/******************************************************************************
*                       FUNCION RETARDO US
* 
*   - Realiza un retardo de uS segun el valor recibido
 *****************************************************************************/

void OW_delayUs(uint16_t i);






#endif	/* XC_HEADER_TEMPLATE_H */

